-- $LastChangedDate: 2008-12-21 15:07:15 -0500 (Sun, 21 Dec 2008) $
-- Joystick handler.
-- C++ handles joystick axis events.
-- Lua handles joystick button events.
-- See module.txt for documentation and pitfalls.

--------------
-- Joystick --
--------------
Joystick = {}

-- Joystick handler (button).
-- sim.Joystick:DequeueButton() returns nil or a table:
-- { buttonNum=int, buttonVal=bool }
function Joystick:Handler()
	-- If player has crashed, ignore joystick input.
	-- (Well, Lua can only discard button events.)
	if ( PlayerActor:IfDestroyed() ) then
		return
	end

	local joyButtonEvent = sim.Joystick:DequeueButton()
	if ( joyButtonEvent ) then
		local pressed = joyButtonEvent.buttonVal
		-- Apply brakes while button is pressed.
		if ( joyButtonEvent.buttonNum == defs.JOYSTICK_BUTTON_BRAKES ) then
			PlayerActor.aircraft:EnableBrakes( joyButtonEvent.buttonVal )
		elseif ( joyButtonEvent.buttonNum == defs.JOYSTICK_BUTTON_FIRE_GUN and pressed ) then
			PlayerActor:FireGun()
		elseif ( joyButtonEvent.buttonNum == defs.JOYSTICK_BUTTON_FIRE_MISSILE and pressed ) then
			PlayerActor:FireMissile()
		elseif ( joyButtonEvent.buttonNum == defs.JOYSTICK_BUTTON_WING_SWEEP_FORWARD and pressed ) then
			Joystick.repeatIncWingSweep = 1
		elseif ( joyButtonEvent.buttonNum == defs.JOYSTICK_BUTTON_WING_SWEEP_BACKWARD and pressed ) then
			Joystick.repeatIncWingSweep = -1
		end
		
		if ( not pressed ) then
			Joystick.repeatIncWingSweep = nil
		end
	end

	-- Repeat some joystick buttons until release.
	if ( Joystick.repeatIncWingSweep ) then
		PlayerActor:IncWingSweep( Joystick.repeatIncWingSweep, "joy" )
	end
end
