-- $LastChangedDate: 2008-12-24 10:42:02 -0500 (Wed, 24 Dec 2008) $
-- This chunk is called every timer-tick.
-- See module.txt for documentation and pitfalls.

-- NOP if controlled by trackball.
if ( sim.argvMap["-t"] ) then
	return
end

-- Call registered timer-tick callbacks.
Timer:Tick()

--------------------------------------------------------------------------------
-- The main timer-tick handler.

-- Keyboard handler.
local keyEvent = sim.Keyboard:DequeueKey()
if ( keyEvent ) then
	Keyboard:Handler( keyEvent )
end

-- Joystick handler.
Joystick:Handler()

-- Update engine sound.
local engineVolume = PlayerActor.aircraft:GetThrottle()  -- throttle equals volume {0.0,..,1.0}
if ( engineVolume < 0.05 or PlayerActor:IfDestroyed() ) then
	PlayerActor.aircraft:StopEngineSound()
else
	PlayerActor.aircraft:PlayEngineSound( engineVolume )
end

-- Update stall warning sound.
if ( PlayerActor.aircraft:GetPhysics():IfStall() ) then
	sim.Sound:Play( "stall.wav.gz", sim.Sound.PLAY_LOOP, 0.6 )
else
	sim.Sound:Stop( "stall.wav.gz" )
end

-- Process commands from the simulator's "command queue".
CommandQueue:Process()  -- cmd.lua

-- CRITICAL: Collect garbage to induce freeing memory of 3D models
-- (which consume large amounts of memory).
if ( (not garbageCollectionTime) or (sim.Program:GetElapsedTime() - garbageCollectionTime > 500) ) then
	garbageCollectionTime = sim.Program:GetElapsedTime()  -- milliseconds
	collectgarbage()
end
